### Prerequisites

- [ ] I have read and understood the [contributing guide](https://github.com/TendTo/dasaturn/blob/main/.github/CONTRIBUTING.rst).
- [ ] The commit message follows the [conventional commits](https://www.conventionalcommits.org/en/v1.0.0/#summary) guidelines.
- [ ] Tested the changes locally with a real Telegram bot.
- [ ] Introduced tests for the changes have been added (for bug fixes / features).
- [ ] Docs have been added/updated (for bug fixes / features).
- [ ] I have updated the `CHANGELOG.rst` file with an overview of the changes made.

### Description

Brief description of what this PR is about.

### (If applicable) Issue closed by this PR

- [closes #issue_number]

### Does this PR introduce a breaking change?

- [ ] Yes
- [ ] No

#### (If yes) What are the changes that might break existing applications?

Description of the changes that might break existing applications.

### Python version you are using

Python version you are using (e.g. 3.10.0).
You can find it out by running `python --version` in your terminal.

### Other information

Any other information that is important to this PR, such as inspirations, further development plans, possible issues left to be solved, etc.
